﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Windows.Forms;
using System.Drawing;

namespace ControlPropertyDefaultValue
{
    #region GlyphAppearances class
    [TypeConverter(typeof(ExpandableObjectConverter))]
    [Description("Exposes GlyphAppearance properties which are specific to a particular CheckState.")]
    public class GlyphAppearances
    {
        private CheckState _checkState = CheckState.Unchecked;
        private GlyphAppearance[] _appearances = new GlyphAppearance[5];
        private EventHandler _propChangeHandler = null;

        public GlyphAppearances(CheckState checkState, EventHandler propChangeHandler)
        {
            this._checkState = checkState;
            this._propChangeHandler = propChangeHandler;
        }

        [Description("Returns a GlyphAppearance which is used to render the checkbox or radio button for the 'normal' state, i.e., when the mouse is not pressed or positioned over the element.")]
        public GlyphAppearance NormalAppearance { get { return this.GetAppearance(VisualState.Normal); } }

        [Description("Returns a GlyphAppearance which is used to render the checkbox or radio button for the 'disabled' state.")]
        public GlyphAppearance DisabledAppearance { get { return this.GetAppearance(VisualState.Disabled); } }

        [Description("Returns a GlyphAppearance which is used to render the checkbox or radio button for the 'pressed' state, i.e., when the left mouse button is pressed over the element.")]
        public GlyphAppearance PressedAppearance { get { return this.GetAppearance(VisualState.Pressed); } }

        [Description("Returns a GlyphAppearance which is used to render the checkbox or radio button for the 'mouse over' state, i.e., when the mouse is positioned over the element.")]
        public GlyphAppearance MouseOverAppearance { get { return this.GetAppearance(VisualState.MouseOver); } }

        [Description("Returns a GlyphAppearance which is used to render the checkbox or radio button for the 'pressed and over' state, i.e., when the mouse is positioned over the element and the left button is pressed.")]
        public GlyphAppearance PressedAndOverAppearance { get { return this.GetAppearance(VisualState.PressedAndOver); } }

        public GlyphAppearance GetAppearance(VisualState state)
        {
            int index = (int)state;
            if (this._appearances[index] == null)
                this._appearances[index] = new GlyphAppearance(state, this._propChangeHandler);

            return this._appearances[index];
        }

        public override string ToString()
        {
            return string.Empty;
        }
    }
    #endregion GlyphAppearances class

    #region GlyphAppearance class
    [TypeConverter(typeof(ExpandableObjectConverter))]
    [Description("Exposes color properties which allow a CheckBox or RadioButton glyph image to be customized.")]
    public class GlyphAppearance
    {
        private VisualState _state = VisualState.Normal;
        private EventHandler _propChangeHandler = null;
        private Color _foreColor = Color.Empty;
        private Color _backColor = Color.Empty;
        private Color _borderColor = Color.Empty;

        public GlyphAppearance(VisualState state, EventHandler propChangeHandler)
        {
            this._state = state;
            this._propChangeHandler = propChangeHandler;
        }

        [Description("The color used to render the checkmark for a CheckBox, or the dot for a RadioButton. Not applicable for appearances exposed by the 'Unchecked' state settings.")]
        public Color ForeColor
        {
            get { return this._foreColor; }
            set { this._foreColor = value; this._propChangeHandler(this, EventArgs.Empty); }
        }

        [Description("The color used to render the area behind the checkmark or dot.")]
        public Color BackColor
        {
            get { return this._backColor; }
            set { this._backColor = value; this._propChangeHandler(this, EventArgs.Empty); }
        }

        [Description("The color used to render the rectangle inside which the checkmark is drawn, or the circle inside which the dot is drawn.")]
        public Color BorderColor
        {
            get { return this._borderColor; }
            set { this._borderColor = value; this._propChangeHandler(this, EventArgs.Empty); }
        }

        public override string ToString()
        {
            return string.Empty;
        }
    }
    #endregion GlyphAppearance class
}
